@@ -3,7 +3,6 @@ package Gearman::Driver::Job;
 use Moose;
 use Gearman::Driver::Adaptor;
 use POE qw(Wheel::Run);
-use Try::Tiny;
 use IO::Socket;
 
 =head1 NAME
@@ -307,42 +306,45 @@ sub BUILD {
 
     $self->{gearman} = Gearman::Driver::Adaptor->new( server => $self->driver->server );
 
+    my $extended_status = $self->driver->extended_status;
+
+    my $decoder = sub { shift };
+    my $encoder = sub { shift };
+
+    if ( my $decoder_method = $self->decode ) {
+        $decoder = sub { return $self->worker->$decoder_method(@_) };
+    }
+    if ( my $encoder_method = $self->encode ) {
+        $encoder = sub { return $self->worker->$encoder_method(@_) };
+    }
+
     my $wrapper = sub {
         my ($job) = @_;
 
         my @args = ($job);
 
-        if ( my $decoder = $self->decode ) {
-            push @args, $self->worker->$decoder( $job->workload );
-        }
-        else {
-            push @args, $job->workload;
-        }
+        push @args, $decoder->( $job->workload );
 
         $self->worker->begin(@args);
 
         my $error;
         my $result;
-        try {
+        eval {
             $result = $self->method->( $self->worker, @args );
-        }
-        catch {
-            $error = $_;
+        };
+        if ($@) {
+            $error = $@;
             $self->lasterror(time) if $self->driver->extended_status;
             $self->lasterror_msg($error) if $self->driver->extended_status;
-        };
+        }
 
-        $self->lastrun(time) if $self->driver->extended_status;
+        $self->lastrun(time) if $extended_status;
 
         $self->worker->end(@args);
 
         die $error if $error;
 
-        if ( my $encoder = $self->encode ) {
-            $result = $self->worker->$encoder($result);
-        }
-
-        return $result;
+        return $encoder->($result);
     };
 
     $self->gearman->add_function( $self->name => $wrapper );
